import unittest

import sys
# automake build dir
sys.path.insert(0, '..')
sys.path.insert(0, '../.libs')
# cmake build dir
sys.path.insert(0, '../../../build/bindings/python')

from pywsman import *



class TestSequenceFunctions(unittest.TestCase):

	def test_enum_release(self):
#		set_debug(1) # enable to print logging to stderr
		client = Client( "http://wsman:secret@localhost:5985/wsman" )
		client.transport().set_auth_method(BASIC_AUTH_STR) # Windows winrm needs this
		options = ClientOptions()
#		uri = "http://schemas.microsoft.com/wbem/wsman/1/wmi/root/cimv2/Win32_OperatingSystem"
		uri = "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_ComputerSystem"
#		options.set_dump_request() # enable to print SOAP request to stdout
		doc = client.enumerate( options, None, uri)
		root = doc.root()
		assert root is not None
		context = root.find(XML_NS_ENUMERATION, "EnumerationContext" )
		doc = client.release( options, uri, context.__str__())
		assert doc is not None
		root = doc.root()
		assert root is not None
		resp = root.find(XML_NS_ADDRESSING, "Action" )
		self.assertEquals( resp.__str__(), XML_NS_ENUMERATION + '/' +  WSENUM_RELEASE_RESP )
		print( "Action %s" % resp )


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python

"""
setup.py file for pywsman
"""

from __future__ import print_function
from distutils.core import setup, Extension
from distutils.command.build import build as _build
import subprocess
import shutil
import sys
import os



PYDIST_VERSION = 0


def errprint(*objs):
    print(*objs, file=sys.stderr)


def get_build_info():
    '''
    Figure out whether we are building from within the openwsman source
    directory, or from a Python source distribution.
    Returns a tuple of (openwsman version string, Bool)
    '''
    try:
        with open(os.devnull, 'w') as devnull:
            subprocess.check_call(['cmake', '-P', 'version.cmake'], stdout=devnull, stderr=devnull)
    except subprocess.CalledProcessError as e:
        if e.returncode == 1:
            errprint('No version.i.in file found -- Building from sdist.')
            in_openwsman = False
        else:
            raise
    except OSError:
        errprint('Failed to run cmake - is it installed? I will assume we are building from an sdist, but I may be wrong!')
        in_openwsman = False
    else:
        errprint('version.i.in file found -- Building from openwsman source.')
        in_openwsman = True
    finally:
        from version import __VERSION__
    return (__VERSION__, in_openwsman)


def copy_files(*source_dirs):
    with open('MANIFEST') as _manifest:
        for _file in _manifest:
            _file = _file.strip()
            dirname = os.path.dirname(_file)
            if dirname and not os.path.exists(dirname):
                os.makedirs(dirname)
            if not os.path.exists(_file):
                copied = False
                for source_dir in source_dirs:
                    try:
                        shutil.copyfile('%s/%s' % (source_dir, _file), _file)
                    except IOError:
                        continue
                    else:
                        copied = True
                        errprint('Copied %s/%s to %s' % (source_dir, _file, _file))
                if not copied:
                    raise


class Build(_build):
    sub_commands = [
        ('build_ext', _build.has_ext_modules),
        ('build_py', _build.has_pure_modules),
        ('build_clib', _build.has_c_libraries),
        ('build_scripts', _build.has_scripts),
    ]


with open('README.rst') as _readme:
    long_description = _readme.read()

version, from_source = get_build_info()

include_dirs = [os.path.abspath(os.path.dirname(__file__)), ]
if from_source:
    copy_files('../..', '../../..')
    include_dirs += ['../..', '../../../include']
else:
    wsman_inc = os.environ.get('OPENWSMAN_INCLUDE', '/usr/include/openwsman')
    include_dirs += [wsman_inc]
for path in include_dirs:
    found = os.path.exists('%s/wsman-client.h' % path)
    if found:
        break
if not found:
    raise RuntimeError(('Could not find openwsman headers.'),
        ('Please install them and/or specify their location using the OPENWSMAN_INCLUDE environment variable.'))


_pywsman = Extension('_pywsman',
    sources = ['openwsman.c', 'openwsman.i', ],
    include_dirs = include_dirs,
    swig_opts = ['-I' + dir for dir in include_dirs] + [
        '-features', 'autodoc',
    ],
    libraries = ['pthread', 'curl', 'wsman', 'wsman_client', 'wsman_curl_client_transport'],
)


setup(name='pywsman',
    version='%s-%s' % (version, PYDIST_VERSION),
    description='Python openwsman bindings.',
    author='The Openwsman project',
    author_email='openwsman-devel@lists.sourceforge.net',
    license='BSD 3-clause',
    long_description=long_description,
    url='http://openwsman.github.io',
    ext_modules=[_pywsman],
    py_modules=['pywsman'],
    classifiers=[
        'License :: OSI Approved :: BSD License',
    ],
    cmdclass={'build': Build},
)




# test loading of pywsman
import sys

# automake build dir
sys.path.insert(0, '..')
sys.path.insert(0, '../.libs')
# cmake build dir
sys.path.insert(0, '../../../build/bindings/python')

from pywsman import *



import unittest
import sys
# automake build dir
sys.path.insert(0, '..')
sys.path.insert(0, '../.libs')
# cmake build dir
sys.path.insert(0, '../../../build/bindings/python')

from pywsman import *

class TestAddSelector(unittest.TestCase):
    def test_add_selector(self):
        client = Client( "http://wsman:secret@localhost:5985/wsman" )
        assert client is not None
        client.transport().set_auth_method(BASIC_AUTH_STR) # Windows winrm needs this
        options = ClientOptions()
        assert options is not None
        options.set_dump_request()
        uri_query = "k1=v1,k2=v2,k3=v3,k4=v4"
        for selector_str in uri_query.split(","):
            (key_asdf, value_asdf) = selector_str.split("=")
            assert key_asdf is not None
            assert value_asdf is not None
            print( "Calling add_selector(%r, %r)" % (key_asdf, value_asdf) )
            options.add_selector(str(key_asdf), str(value_asdf))
        dummy = client.invoke(options, "http://uri", "method", XmlDoc("dummy doc"))

if __name__ == '__main__':
    unittest.main()



import unittest

import sys
# automake build dir
sys.path.insert(0, '..')
sys.path.insert(0, '../.libs')
# cmake build dir
sys.path.insert(0, '../../../build/bindings/python')

from pywsman import *

class TestAddSelector(unittest.TestCase):
    def test_add_selector(self):
        options = ClientOptions()
        assert options is not None
        options.add_selector("foo", "bar")

if __name__ == '__main__':
    unittest.main()
    


import unittest

import sys
# automake build dir
sys.path.insert(0, '..')
sys.path.insert(0, '../.libs')
# cmake build dir
sys.path.insert(0, '../../../build/bindings/python')

from pywsman import *



class TestSequenceFunctions(unittest.TestCase):

	def test_enum(self):
#		set_debug(1) # enable to print logging to stderr
		client = Client( "http://wsman:secret@localhost:5985/wsman" )
		client.transport().set_auth_method(BASIC_AUTH_STR) # Windows winrm needs this
		options = ClientOptions()
#		options.set_dump_request() # enable to print SOAP request to stdout
		doc = client.enumerate( options, None, "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_ComputerSystem")
#		doc = client.enumerate( options, None, "http://schemas.microsoft.com/wbem/wsman/1/wmi/root/cimv2/Win32_OperatingSystem")
		assert doc is not None
		root = doc.root()
		assert root is not None
		context = root.find(XML_NS_ENUMERATION, "EnumerationContext" )
		print( "Context: %s" % context )
	def test_enum_and_pull(self):
#		set_debug(1) # enable to print logging to stderr
		client = Client( "http://wsman:secret@localhost:5985/wsman" )
		client.transport().set_auth_method(BASIC_AUTH_STR) # Windows winrm needs this
		options = ClientOptions()
#		options.set_dump_request() # enable to print SOAP request to stdout
		doc = client.enumerate( options, None, "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_ComputerSystem")
#		doc = client.enumerate( options, None, "http://schemas.microsoft.com/wbem/wsman/1/wmi/root/cimv2/Win32_OperatingSystem")
		root = doc.root()
		assert root is not None
		context = root.find(XML_NS_ENUMERATION, "EnumerationContext" )
		doc = client.pull( options , None, "http://schemas.dmtf.org/wbem/wscim/1/cim-schema/2/CIM_ComputerSystem", context.__str__())
		assert doc is not None
		root = doc.root()
		assert root is not None
		pullresp = root.find(XML_NS_ENUMERATION, "PullResponse" )
		assert pullresp is not None
		print( "Pull response: %s" % pullresp.string() )

if __name__ == '__main__':
    unittest.main()



import unittest

import sys
# automake build dir
sys.path.insert(0, '..')
sys.path.insert(0, '../.libs')
# cmake build dir
sys.path.insert(0, '../../../build/bindings/python')

from pywsman import *



class TestSequenceFunctions(unittest.TestCase):

   def test_identify(self):
#     set_debug(1) # enable to print logging to stderr
      client = Client( "http://wsman:secret@localhost:5985/wsman" )
      assert client is not None
      client.transport().set_auth_method(BASIC_AUTH_STR) # Windows winrm needs this
      options = ClientOptions()
      assert options is not None
#     options.set_dump_request() # enable to print SOAP request to stdout
      doc = client.identify( options )
      assert doc is not None
#      print "Document [%s]" % doc
      root = doc.root()
      assert root is not None
#      print "Root [%s]" % root
      prot_version = root.find( XML_NS_WSMAN_ID, "ProtocolVersion" )
      prod_vendor = root.find( XML_NS_WSMAN_ID, "ProductVendor" )
      prod_version = root.find( XML_NS_WSMAN_ID, "ProductVersion" )
      print("Protocol %s, Vendor %s, Version %s"  %( prot_version, prod_vendor, prod_version ))


if __name__ == '__main__':
    unittest.main()



##############################################################################
# Copyright (C) 2008 Novell Inc. All rights reserved.
# Copyright (C) 2008 SUSE Linux Products GmbH. All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 
#   - Redistributions of source code must retain the above copyright notice,
#     this list of conditions and the following disclaimer.
# 
#   - Redistributions in binary form must reproduce the above copyright notice,
#     this list of conditions and the following disclaimer in the documentation
#     and/or other materials provided with the distribution.
# 
#   - Neither the name of Novell Inc. nor of SUSE Linux Products GmbH nor the
#     names of its contributors may be used to endorse or promote products
#     derived from this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL Novell Inc. OR SUSE Linux Products GmbH OR
# THE CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
##############################################################################

import types
import syslog
import sys





#
# testing EndPointReference
#
import unittest
import sys
# automake build dir
sys.path.insert(0, '..')
sys.path.insert(0, '../.libs')
# cmake build dir
sys.path.insert(0, '../../../build/bindings/python')

from pywsman import *

class TestEndPointReference(unittest.TestCase):
    def test_endpoint_reference(self):
        epr = EndPointReference("http://schemas.microsoft.com/wbem/wsman/1/wmi/root/cimv2/Win32_Service?Name=Windows&Vendor=Microsoft")
        assert epr is not None
        print( epr.to_xml() )
        s1 = epr.selector("Name")
        assert s1 is not None
        s2 = epr.selector("Vendor")
        assert s2 is not None
        names = epr.selector_names()
        print( "Names: ", names )

if __name__ == '__main__':
    unittest.main()



import unittest
import sys

# automake build dir
sys.path.insert(0, '..')
sys.path.insert(0, '../.libs')
# cmake build dir
sys.path.insert(0, '../../../build/bindings/python')

from pywsman import *



class TestSequenceFunctions(unittest.TestCase):
	def test_client_constructor_uri_simple(self):
		client = Client("http://localhost")
		self.assertEqual(client.scheme() , "http")
		self.assertEqual(client.host() , "localhost")
	def test_client_constructor_uri(self):
		client = Client( "https://wsman:secret@localhost:5985/wsman" )
		assert client is not None
		self.assertEqual(client.scheme() , "https" )
		self.assertEqual(client.user() , "wsman" )
		self.assertEqual(client.password() , "secret" )
		self.assertEqual(client.host() , "localhost" )
		self.assertEqual(client.port() , 5985 )
		self.assertEqual(client.path() , "/wsman" )

	def test_client_constructor_full(self):
		client = Client( "localhost", 5985, "/wsman", "http", "wsman", "secret" )
		assert client is not None
		self.assertEqual(client.scheme() , "http" )
		self.assertEqual(client.user() , "wsman" )
		self.assertEqual(client.password() , "secret")
		self.assertEqual(client.host() , "localhost" )
		self.assertEqual(client.port() ,5985 )
		self.assertEqual(client.path() ,"/wsman")

	def test_client_options_constructor(self):
		options = ClientOptions()
		assert options is not None

	def test_identify(self):
		client = Client( "http://wsman:secret@localhost:5985/wsman" )
		assert client is not None
		options = ClientOptions()
		assert options is not None
		doc = client.identify( options )
		assert doc is not None
		root = doc.root()
		assert root is not None
		prot_version = root.find( XML_NS_WSMAN_ID, "ProtocolVersion" )
		prod_vendor = root.find( XML_NS_WSMAN_ID, "ProductVendor" )
		prod_version = root.find(XML_NS_WSMAN_ID, "ProductVersion" )
		print "Protocol %s, Vendor %s, Version %s"  %( prot_version, prod_vendor, prod_version )


if __name__ == '__main__':
    unittest.main()
